package com.yinet.system.mapper;

import com.yinet.system.domain.Bjlb;
import java.util.List;
import java.util.Map;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author yinet
 * @date 2020-04-22
 */
public interface BjlbMapper
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public Bjlb selectBjlbById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param bjlb 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<Bjlb> selectBjlbList(Bjlb bjlb);

    /**
     * 新增【请填写功能名称】
     *
     * @param bjlb 【请填写功能名称】
     * @return 结果
     */
    public int insertBjlb(Bjlb bjlb);

    /**
     * 修改【请填写功能名称】
     *
     * @param bjlb 【请填写功能名称】
     * @return 结果
     */
    public int updateBjlb(Bjlb bjlb);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteBjlbById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBjlbByIds(String[] ids);

    //统计
    public int selectBjlbVoCountByConditiond(Map<String,Object> selMap);
    //列表
    public List<Bjlb> selectBjlbVoByConditiond(Map<String,Object> selMap);

}
